package dev.fyloz.trial.colorrecipesexplorer.core.configuration;

import dev.fyloz.trial.colorrecipesexplorer.ColorRecipesExplorerApplication;
import dev.fyloz.trial.colorrecipesexplorer.core.Preferences;
import dev.fyloz.trial.colorrecipesexplorer.core.services.PasswordService;
import dev.fyloz.trial.colorrecipesexplorer.core.services.files.FilesService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.MessageSource;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.io.IOException;
import java.util.List;

@Configuration
public class SpringConfiguration {

    @Value("${url.useport}")
    private boolean usePort;

    @Value("${server.upload-directory}")
    private String uploadDirectory;

    @Value("${server.passwords.file-name}")
    private String passwordsFileName;

    private FilesService filesService;
    private MessageSource messageSource;

    @Autowired
    public SpringConfiguration(FilesService filesService, MessageSource messageSource) {
        this.filesService = filesService;
        this.messageSource = messageSource;
    }

    @Bean
    public void setPreferences() {
        Preferences.urlUsePort = usePort;
        Preferences.uploadDirectory = uploadDirectory;
        Preferences.passwordsFileName = passwordsFileName;
        Preferences.logger = LoggerFactory.getLogger(ColorRecipesExplorerApplication.class);
        Preferences.messageSource = messageSource;
    }

    @Bean
    public void initializePasswords() {
        Logger logger = Preferences.logger;
        String filePath = filesService.getPath(passwordsFileName);

        logger.info("Le fichier des utilisateurs se situe à: " + filesService.getFile(filePath).getAbsolutePath());

        try {
            if (!filesService.exists(filePath)) filesService.create(filePath);
            List<String> fileContent = filesService.readAsStrings(filePath);

            if (fileContent.size() < 1) {
                logger.warn("Aucun mot de passe trouvé. Il sera impossible d'utiliser certaines fonctionnalités de l'application.");
            }

            for (String line : fileContent) {
                PasswordService.addPassword(line);
            }
        } catch (IOException e) {
            logger.error("Une erreur est survenue lors du chargement du fichier des utilisateurs", e);
            logger.warn("Il sera impossible d'utiliser certaines fonctionnalités de l'application.");
        }
    }

}
